==> nextcloud-29.0.5.tgz: nextcloud/apps/user_status/l10n/gl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estados recentes",
    "No recent status changes" : "Non hai cambios de estado recentes",
    "In a meeting" : "Nunha xuntanza",
    "Commuting" : "De casa ao traballo ou ao revés",
    "Out sick" : "Enfermo",
    "Vacationing" : "De vacacións",
    "Out of office" : "Fóra da oficina",
    "Working remotely" : "Traballando en remoto",
    "In a call" : "Nunha chamada",
    "User status" : "Estado do usuario",
    "Clear status after" : "Limpar o estado após",
    "Emoji for your status message" : "«Emoji» para a súa mensaxe de estado",
    "What is your status?" : "Cal é o seu estado?",
    "Predefined statuses" : "Estados predefinidos",
    "Previously set" : "Estabelecido previamente",
    "Reset status" : "Restabelecer o estado",
    "Set status" : "Definir o estado",
    "Online status" : "Estado en liña",
    "Status message" : "Mensaxe de estado",
    "Your status was set automatically" : "O seu estado foi estabelecido automaticamente",
    "Clear status message" : "Limpar a mensaxe de estado",
    "Set status message" : "Definir a mensaxe de estado",
    "Reset status to \"{icon} {message}\"" : "Restabelecer o estado a «{icon} {message}»",
    "Reset status to \"{message}\"" : "Restabelecer o estado a «{message}»",
    "Reset status to \"{icon}\"" : "Restabelecer o estado a «{icon}»",
    "There was an error saving the status" : "Produciuse un erro ao gardar o estado",
    "There was an error clearing the status" : "Produciuse un erro ao limpar o estado",
    "There was an error reverting the status" : "Produciuse un erro ao reverter o estado",
    "Don't clear" : "Non limpar",
    "Today" : "Hoxe",
    "This week" : "Esta semana",
    "Online" : "En liña",
    "Away" : "Ausente",
    "Do not disturb" : "Non molestar",
    "Invisible" : "Invisíbel",
    "Offline" : "Sen conexión",
    "There was an error saving the new status" : "Produciuse un erro ao gardar o novo estado",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Silenciar todas as notificacións",
    "Appear offline" : "Aparece coma sen conexión"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.10.tgz: nextcloud/apps/user_status/l10n/gl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estados recentes",
    "No recent status changes" : "Non hai cambios de estado recentes",
    "In a meeting" : "Nunha xuntanza",
    "Commuting" : "De casa ao traballo ou ao revés",
    "Out sick" : "Enfermo",
    "Vacationing" : "De vacacións",
    "Out of office" : "Fóra da oficina",
    "Working remotely" : "Traballando en remoto",
    "In a call" : "Nunha chamada",
    "User status" : "Estado do usuario",
    "Clear status after" : "Limpar o estado após",
    "Emoji for your status message" : "«Emoji» para a súa mensaxe de estado",
    "What is your status?" : "Cal é o seu estado?",
    "Predefined statuses" : "Estados predefinidos",
    "Previously set" : "Estabelecido previamente",
    "Reset status" : "Restabelecer o estado",
    "Reset status to \"{icon} {message}\"" : "Restabelecer o estado a «{icon} {message}»",
    "Reset status to \"{message}\"" : "Restabelecer o estado a «{message}»",
    "Reset status to \"{icon}\"" : "Restabelecer o estado a «{icon}»",
    "There was an error saving the status" : "Produciuse un erro ao gardar o estado",
    "There was an error clearing the status" : "Produciuse un erro ao limpar o estado",
    "There was an error reverting the status" : "Produciuse un erro ao reverter o estado",
    "Set status" : "Definir o estado",
    "Online status" : "Estado en liña",
    "Status message" : "Mensaxe de estado",
    "Set absence period" : "Definir o período de ausencia",
    "Set absence period and replacement" : "Definir o período de ausencia e substitución",
    "Your status was set automatically" : "O seu estado foi estabelecido automaticamente",
    "Clear status message" : "Limpar a mensaxe de estado",
    "Set status message" : "Definir a mensaxe de estado",
    "Don't clear" : "Non limpar",
    "Today" : "Hoxe",
    "This week" : "Esta semana",
    "Online" : "En liña",
    "Away" : "Ausente",
    "Do not disturb" : "Non molestar",
    "Invisible" : "Invisíbel",
    "Offline" : "Sen conexión",
    "There was an error saving the new status" : "Produciuse un erro ao gardar o novo estado",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Enmudecer todas as notificacións",
    "Appear offline" : "Aparece coma sen conexión"
},
"nplurals=2; plural=(n != 1);");
